@@ -181,6 +181,8 @@ const char *Audio::getExtension(Encoding encoding)
 		return ".sx";
 	case g721ADPCM:
 		return ".adpcm";
+	case g723_2bit:
+		return ".a16";
 	case g723_3bit:
 		return ".a24";
 	case g723_5bit:
@@ -241,6 +243,8 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return alawAudio;
 	else if(!stricmp(name, "linear") || !stricmp(name, "pcm16") || !stricmp(name, "pcm") || !stricmp(name, "l16"))
 		return pcm16Mono;
+	else if(!stricmp(name, "stereo"))
+		return pcm16Stereo;
 	else if(!stricmp(name, "cda"))
 		return cdaStereo;
 	else if(!stricmp(name, "gsm"))
@@ -253,11 +257,11 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return pcm32Mono;
 	else if(!stricmp(name, "adpcm"))
 		return g721ADPCM;
-	else if(!stricmp(name, "g721"))
+	else if(!stricmp(name, "g721") || !stricmp(name, "g.721"))
 		return g721ADPCM;
-	else if(!stricmp(name, "g726_32"))
+	else if(!stricmp(name, "g726-32"))
 		return g721ADPCM;
-	else if(!stricmp(name, "g729"))
+	else if(!stricmp(name, "g729") || !stricmp(name, "g.729"))
 		return g729Audio;
 	else if(!stricmp(name, "ilbc"))
 		return ilbcAudio;
@@ -277,11 +281,11 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return sx96Voice;
 	else if(!stricmp(name, "spx") || !stricmp(name, "speex"))
 		return speexVoice;
-	else if(!stricmp(name, "g723_16") || !stricmp(name, "g.723_16"))
+	else if(!stricmp(name, "g723-16") || !stricmp(name, "g.723-16"))
 		return g723_2bit;
-	else if(!stricmp(name, "g723_24") || !stricmp(name, "g.723_24"))
+	else if(!stricmp(name, "g723-24") || !stricmp(name, "g.723-24"))
 		return g723_3bit;
-	else if(!stricmp(name, "g723_40") || !stricmp(name, "g.723_40"))
+	else if(!stricmp(name, "g723-40") || !stricmp(name, "g.723-40"))
 		return g723_5bit;
 	else if(!stricmp(name, ".al") || !stricmp(name, ".alaw"))
 		return alawAudio;
@@ -289,17 +293,19 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return mulawAudio;
 	else if(!stricmp(name, ".sw") || !stricmp(name, ".raw") || !stricmp(name, ".pcm"))
 		return pcm16Mono;
-	else if(!stricmp(name, ".vox"))
+	else if(!stricmp(name, ".vox") || !stricmp(name, "vox"))
 		return voxADPCM;
 	else if(!stricmp(name, ".adpcm"))
 		return g721ADPCM;
 	else if(!stricmp(name, ".g721"))
 		return g721ADPCM;
-	else if(!stricmp(name, ".a32"))
+	else if(!stricmp(name, ".a32") || !stricmp(name, "a32"))
 		return g721ADPCM;
-	else if(!stricmp(name, ".a24"))
+	else if(!stricmp(name, ".a24") || !stricmp(name, "a24"))
 		return g723_3bit;
-	else if(!stricmp(name, ".a40"))
+	else if(!stricmp(name, ".a16") || !stricmp(name, "a16"))
+		return g723_2bit;
+	else if(!stricmp(name, ".a40") || !stricmp(name, "a40"))
 		return g723_5bit;
 	else if(!stricmp(name, ".g723"))
 		return g723_3bit;
@@ -926,6 +932,7 @@ Audio::timeout_t Audio::getFraming(Encoding encoding, timeout_t timeout)
 	case gsmVoice:
 	case speexVoice:
 	case speexAudio:
+	case speexUltra:
 		fa = 20;
 		break;
 	case ilbcAudio:
@@ -971,6 +978,8 @@ int Audio::getCount(Encoding encoding)
 		return 160;
 	case speexAudio:
 		return 320;
+	case speexUltra:
+		return 640;
 	case unknownEncoding:
 		return 0;
 	case g723_2bit:
@@ -1120,6 +1129,8 @@ Audio::Rate Audio::getRate(Encoding encoding)
 		return rate44khz;
 	case speexAudio:
 		return rate16khz;
+	case speexUltra:
+		return rate32khz;
 	default:
 		return rate8khz;
 	}
