@@ -90,16 +90,6 @@ int main(int argc, char **argv)
 	exit(-1);
 }
 
-static const char *fname(const char *cp)
-{ 
-        const char *fn = strrchr(cp, '/');
-        if(!fn)
-                fn = strrchr(cp, '\\');
-        if(fn)
-                return ++fn;
-        return cp;
-}
-
 using namespace ost;
 
 bool Tool::isFile(const char *path)
